#!/bin/bash
#
# usage : modcount.sh -t (modules|libraries|features) <platform>
#
# DATE :
# 2012-09-28
#
# AUTHORS :
# stephane@koumbit.org
#
# POSSIBLE TODOS :
# * parse module.info to know version of modules
# * add intelligence to find libraries and/or features located in non-standard places
# * ask a bash expert for a script review ...
#

while getopts ":t:" opt; do
  case $opt in

    t)
      shift 2
      echo "Compiling $OPTARG list..." >&2
      case $OPTARG in

        modules)
          # We assume that modules are found in the modules/ folder, but there could be features and other such items
          CHECKLIST="$1/sites/*/modules $1/sites/*/modules/contrib"
          ;;

        libraries)
          CHECKLIST="$1/sites/*/libraries"
          ;;

        features)
          # Not always reliable...
          CHECKLIST="$1/sites/*/modules/features"
          ;;

      esac
      ;;

    \?)
      echo "Invalid option: -$OPTARG" >&2
      ;;

    :)
      echo "Option -$OPTARG requires an argument." >&2
      exit 1
      ;;

  esac
done

echo "We will be searching in $CHECKLIST."

nice find $CHECKLIST -maxdepth 1 -type d -not -regex '\(sites\/all\/\|.*\/\(modules\|contrib\|custom\|patches\|features\|\.git\)\)' | rev | cut -d \/ -f1 | rev | sort | uniq -ic | sort -rn
